@@ -214,4 +214,4 @@ class App:
         print(f"[INFO] Running on http://{self.host}:{self.port}")
         print(f"[INFO] Press CTRL + C to stop")
         uvicorn.run(self, host="127.0.0.1", port=5000,
-                    log_level="critical", interface="wsgi")
+                    log_level="critical")
